@@ -13,7 +13,6 @@
 
 use 5.036;
 use lib               qw(../lib);
-use Digest::CRC       qw();
 use File::Basename    qw(basename);
 use Compression::Util qw(:all);
 
@@ -43,7 +42,7 @@ open my $out_fh, '>:raw', $output
 print $out_fh $MAGIC, $CM, $FLAGS, $MTIME, $XFLAGS, $OS;
 
 my $total_length = 0;
-my $crc32        = Digest::CRC->new(type => "crc32");
+my $crc32        = 0;
 
 my $bitstring  = '';
 my $block_type = '10';    # 00 = store; 10 = LZSS + Fixed codes; 01 = LZSS + Dynamic codes
@@ -112,7 +111,7 @@ while (read($in_fh, (my $chunk), CHUNK_SIZE)) {
     my $bits_len = length($bitstring);
     print $out_fh pack('b*', substr($bitstring, 0, $bits_len - ($bits_len % 8), ''));
 
-    $crc32->add($chunk);
+    $crc32 = crc32($chunk, $crc32);
     $total_length += $chunk_len;
 }
 
@@ -120,8 +119,8 @@ if ($bitstring ne '') {
     print $out_fh pack('b*', $bitstring);
 }
 
-print $out_fh pack('b*', int2bits_lsb($crc32->digest, 32));
-print $out_fh pack('b*', int2bits_lsb($total_length,  32));
+print $out_fh pack('b*', int2bits_lsb($crc32,        32));
+print $out_fh pack('b*', int2bits_lsb($total_length, 32));
 
 close $in_fh;
 close $out_fh;
